-- Data export scripts 
-- Copyright (C) 2004, Eagle Dynamics.
-- See http://www.lua.org for Lua script system info 
-- We recommend to use the LuaSocket addon (http://www.tecgraf.puc-rio.br/luasocket)
-- to use standard network protocols in Lua scripts. 

-- Expand the functionality of following functions for your external application needs.
-- Look into ./Temp/Error.log for this script errors, please.

--  loView_yaw = 7
--  loView_Pitch = 8
--  loView_Zoom = 9
  loView_yaw = 10
  loView_Pitch = 11
  loView_Zoom = 12

-- Uncomment this function to enable data export!

function LuaExportStart()
-- Works once just before mission start.

-- Make initializations of your files or connections here.
-- For example:
-- 1) File
	local file = io.open("./Temp/FreeTrack.log", "w")
	if file then
		io.output(file)
	end
-- 2) Socket
	local path = "./luasocket.dll"
	local f = assert(loadlib(path, "luaopen_socket"))
	f()
	local host = host or "localhost"
	local port = port or 8080
	if socket then
		c, e = socket.connect(host, port) -- connect to the listener socket
	end

end



function LuaExportBeforeNextFrame()
-- Works just before every simulation frame.

-- Call Lo*() functions to set data to Lock On here
-- For example:
--	LoSetCommand(3, 0.25) -- rudder 0.25 right 
--	LoSetCommand(64) -- increase thrust

	local coef

        if c then
        	s, e = c:send("view\n")
                local s = c:receive()

		assert(loadstring("view = { " .. s .. " }"))()

--		io.write(string.format("yaw = %.3f pitch = %.3f zoom = %.3f enabled=%d\n", view.yaw, view.pitch, view.zoom, view.enabled))

		if view.enabled > 0 then
			LoSetCommand(loView_yaw, -view.yaw)
			LoSetCommand(loView_Pitch, -view.pitch)
			LoSetCommand(loView_Zoom, view.zoom*0.6)
		end
        end
end



function LuaExportAfterNextFrame()
-- Works just after every simulation frame.

-- Call Lo*() functions to get data from Lock On here.
-- For example:
--	local t = LoGetModelTime()
--	local name = LoGetPilotName()
--	local altBar = LoGetAltitudeAboveSeaLevel()
--	local altRad = LoGetAltitudeAboveGroundLevel()
--	local pitch, bank, yaw = LoGetADIPitchBankYaw()
-- Then send data to your file or to your receiving program:
-- 1) File
--	io.write(string.format("t = %.2f, name = %s, altBar = %.2f, altRad = %.2f, pitch = %.2f, bank = %.2f, yaw = %.2f\n", t, name, altBar, altRad, pitch, bank, yaw))
-- 2) Socket
--	if c then
--		s, e = c:send(string.format("t = %.2f, name = %s, altBar = %.2f, alrRad = %.2f, pitch = %.2f, bank = %.2f, yaw = %.2f\n", t, name, altRad, altBar, pitch, bank, yaw))
--	end

end

function LuaExportStop()
-- Works once just after mission stop.

-- Close files and/or connections here.
-- For example:
-- 1) File
	io.close()
-- 2) Socket
	if c then
--		s, e = c:send("quit") -- to close the listener socket
		c:close()
	end

end

function LuaExportActivityNextEvent(t)
	local tNext = t

-- Put your event code here and increase tNext for the next event
-- so this function will be called automatically at your custom
-- model times. 
-- If tNext == t then the activity will be terminated.

	return tNext
end

--[[ You can use registered Lock On internal data exporting functions in this script
and in your scripts called from this script.

Note: following functions are implemented for exporting technology experiments only,
so they may be changed or removed in the future by developers.

All returned values are Lua numbers if not pointed other type.

Output:
LoGetModelTime() -- returns current model time (args - 0, results - 1 (sec))
LoGetMissionStartTime() -- returns mission start time (args - 0, results - 1 (sec))
LoGetPilotName() -- (args - 0, results - 1 (text string))
LoGetIndicatedAirSpeed() -- (args - 0, results - 1 (knots))
LoGetTrueAirSpeed() -- (args - 0, results - 1 (knots))
LoGetAltitudeAboveSeaLevel() -- (args - 0, results - 1 (feet))
LoGetAltitudeAboveGroundLevel() -- (args - 0, results - 1 (feet))
LoGetAngleOfAttack() -- (args - 0, results - 1 (degrees))
LoGetAccelerationUnits() -- (args - 0, results - 1 (G))
LoGetVerticalVelocity() -- (args - 0, results - 1(feet per sec))
LoGetADIPitchBankYaw() -- (args - 0, results - 3 (degrees))

Input:
LoSetCommand(command, value) -- (args - 2, results - 0)
-1.0 <= value <= 1.0

Some analogous joystick/mouse input commands:
command = 1 - joystick pitch
command = 2 - joystick roll
command = 3 - joystick rudder
-- Thrust values are inverted for some internal reasons, sorry.
command = 4 - joystick thrust (both engines)
command = 5 - joystick left engine thrust
command = 6 - joystick right engine thrust
command = 7 - mouse camera rotate left/right  
command = 8 - mouse camera rotate up/down
command = 9 - mouse camera zoom 
command = 10 - joystick camera rotate left/right
command = 11 - joystick camera rotate up/down
command = 12 - joystick camera zoom 
command = 13 - mouse pitch
command = 14 - mouse roll
command = 15 - mouse rudder
-- Thrust values are inverted for some internal reasons, sorry.
command = 16 - mouse thrust (both engines)
command = 17 - mouse left engine thrust
command = 18 - mouse right engine thrust
command = 19 - mouse trim pitch
command = 20 - mouse trim roll
command = 21 - mouse trim rudder
command = 22 - joystick trim pitch
command = 23 - joystick trim roll
command = 24 - trim rudder
command = 25 - mouse rotate radar antenna left/right
command = 26 - mouse rotate radar antenna up/down
command = 27 - joystick rotate radar antenna left/right
command = 28 - joystick rotate radar antenna up/down
command = 29 - mouse MFD zoom
command = 30 - joystick MFD zoom
command = 31 - mouse move selecter left/right
command = 32 - mouse move selecter up/down
command = 33 - joystick move selecter left/right
command = 34 - joystick move selecter up/down

Some discrete keyboard input commands (value is absent):
command = 7 - cockpit view (F1)
command = 8 - external view (F2)
command = 64 - increase thrust (both engines)
command = 65 - decrease thrust (both engines)
command = 72 - flaps on/off
command = 73 - air brake on/off
command = 84 - cannon fire on
command = 85 - cannon fire off
command = 161 - increase left engine thrust
command = 162 - decrease left engine thrust
command = 163 - increase right engine thrust
command = 164 - decrease right engine thrust
command = 350 - weapons pickle on
command = 351 - weapons pickle off

To be continued...
--]]

